
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    print qq{1..0 # SKIP these tests are for testing by the author\n};
    exit
  }
}

use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::EOL 0.18

use Test::More 0.88;
use Test::EOL;

my @files = (
    'lib/Tapper/TAP/Harness.pm',
    't/00-load.t',
    't/archive-with-empty.t',
    't/archive.t',
    't/author-eol.t',
    't/author-no-tabs.t',
    't/author-pod-syntax.t',
    't/backcompat/harness.t',
    't/backcompat/mini_tap.t',
    't/backcompat/strange_tap.t',
    't/backcompat/strange_tap_STM.t',
    't/backcompat/strange_tap_kvm_building.t',
    't/backcompat/strange_tap_lazy_plan.t',
    't/backcompat/strange_tap_oprofile_explicit_sections.t',
    't/backcompat/strange_tap_proc_interrupts.t',
    't/backcompat/strange_tap_rhv7.t',
    't/backcompat/strange_tap_slbench.t',
    't/backcompat/strange_tap_v13_and_yaml.t',
    't/backcompat/tap_archive_STM_explicit_section.tap',
    't/backcompat/tap_archive_STM_explicit_section_no_yaml.tap',
    't/backcompat/tap_archive_daily_report.tap',
    't/backcompat/tap_archive_headers_kvm.tap',
    't/backcompat/tap_archive_headers_simnow.tap',
    't/backcompat/tap_archive_headers_xen.tap',
    't/backcompat/tap_archive_kernbench.tap',
    't/backcompat/tap_archive_kernbench2.tap',
    't/backcompat/tap_archive_kernbench3.tap',
    't/backcompat/tap_archive_kernbench4.tap',
    't/backcompat/tap_archive_kernbench5.tap',
    't/backcompat/tap_archive_kernbench_lazy_plan.tap',
    't/backcompat/tap_archive_kernbench_no_v13.tap',
    't/backcompat/tap_archive_kvm_building.tap',
    't/backcompat/tap_archive_kvm_migration.tap',
    't/backcompat/tap_archive_logfile_lazy_plan.tap',
    't/backcompat/tap_archive_mini.tap',
    't/backcompat/tap_archive_mini_version.tap',
    't/backcompat/tap_archive_missing_yaml.tap',
    't/backcompat/tap_archive_much_whitespace.tap',
    't/backcompat/tap_archive_oprofile_explicit_sections.tap',
    't/backcompat/tap_archive_oprofile_reallive.tap',
    't/backcompat/tap_archive_rhv7.tap',
    't/backcompat/tap_archive_sections_with_whitespace.tap',
    't/backcompat/tap_archive_slbench.tap',
    't/backcompat/tap_archive_tapper.tap',
    't/backcompat/tap_archive_tapper_lazy_plan.tap',
    't/backcompat/tap_archive_tapper_prove3.15.tap',
    't/backcompat/tap_archive_tapper_reports_dpath_prove3.15.tap',
    't/backcompat/tap_with_version.t',
    't/backcompat/tapper_headers.t',
    't/commented-plan.t',
    't/commented-plan.tap',
    't/dot_section.t',
    't/dot_section.tap',
    't/harness-provetap.t',
    't/harness.t',
    't/mini_tap.t',
    't/release-pod-coverage.t',
    't/single_lazy_plan.t',
    't/strange_tap.t',
    't/strange_tap_STM.t',
    't/strange_tap_benchmark-s3.t',
    't/strange_tap_kvm_building.t',
    't/strange_tap_lazy_plan.t',
    't/strange_tap_oprofile_explicit_sections.t',
    't/strange_tap_proc_interrupts.t',
    't/strange_tap_rhv7.t',
    't/strange_tap_slbench.t',
    't/strange_tap_v13_and_yaml.t',
    't/tap-archive-3-with-empty.tgz',
    't/tap_archive_STM_explicit_section.tap',
    't/tap_archive_STM_explicit_section_no_yaml.tap',
    't/tap_archive_benchmark-s3.tap',
    't/tap_archive_daily_report.tap',
    't/tap_archive_headers_kvm.tap',
    't/tap_archive_headers_kvm2.tap',
    't/tap_archive_headers_simnow.tap',
    't/tap_archive_headers_simnow2.tap',
    't/tap_archive_headers_xen.tap',
    't/tap_archive_headers_xen2.tap',
    't/tap_archive_kernbench.tap',
    't/tap_archive_kernbench2.tap',
    't/tap_archive_kernbench3.tap',
    't/tap_archive_kernbench4.tap',
    't/tap_archive_kernbench5.tap',
    't/tap_archive_kernbench_lazy_plan.tap',
    't/tap_archive_kernbench_no_v13.tap',
    't/tap_archive_kvm_building.tap',
    't/tap_archive_kvm_migration.tap',
    't/tap_archive_logfile_lazy_plan.tap',
    't/tap_archive_mini.tap',
    't/tap_archive_mini_version.tap',
    't/tap_archive_missing_yaml.tap',
    't/tap_archive_much_whitespace.tap',
    't/tap_archive_oprofile_explicit_sections.tap',
    't/tap_archive_oprofile_reallive.tap',
    't/tap_archive_rhv7.tap',
    't/tap_archive_sections_with_whitespace.tap',
    't/tap_archive_slbench.tap',
    't/tap_archive_tapper.tap',
    't/tap_archive_tapper_lazy_plan.tap',
    't/tap_archive_tapper_prove3.15.tap',
    't/tap_archive_tapper_reports_dpath_prove3.15.tap',
    't/tap_archive_tapper_single_lazy_plan.tap',
    't/tap_with_version.t',
    't/tapper_headers.t',
    't/tapper_headers2.t'
);

eol_unix_ok($_, { trailing_whitespace => 0 }) foreach @files;
done_testing;
